@@ -25,24 +25,25 @@
 #include <QNetworkInterface>
 #include <QTimer>
 
+#include <bcodec/bencoder.h>
 #include <dht/dhtbase.h>
-#include <magnet/magnetlink.h>
-#include <torrent/globals.h>
 #include <interfaces/functions.h>
+#include <magnet/magnetlink.h>
+#include <peer/authenticationmonitor.h>
 #include <settings.h>
+#include <torrent/globals.h>
+#include <torrent/server.h>
 #include <upnp/upnpmcastsocket.h>
+#include <util/error.h>
 #include <util/functions.h>
 #include <util/log.h>
-#include <util/error.h>
-#include <torrent/server.h>
-#include <bcodec/bencoder.h>
-#include <peer/authenticationmonitor.h>
-
 
 using namespace kt;
 using namespace bt;
 
-MagnetTest::MagnetTest(const bt::MagnetLink& mlink, QObject* parent) : QObject(parent), mlink(mlink)
+MagnetTest::MagnetTest(const bt::MagnetLink &mlink, QObject *parent)
+    : QObject(parent)
+    , mlink(mlink)
 {
     upnp = new bt::UPnPMCastSocket();
     connect(upnp, &bt::UPnPMCastSocket::discovered, this, &MagnetTest::routerDiscovered);
@@ -59,8 +60,7 @@ MagnetTest::~MagnetTest()
     delete upnp;
 }
 
-
-void MagnetTest::routerDiscovered(bt::UPnPRouter* router)
+void MagnetTest::routerDiscovered(bt::UPnPRouter *router)
 {
     net::Port port;
     port.number = Settings::dhtPort();
@@ -79,12 +79,11 @@ void MagnetTest::start()
 
     // Make sure network interface is set properly before server is initialized
     if (!Settings::networkInterface().isEmpty()) {
-        //QList<QNetworkInterface> iface_list = QNetworkInterface::allInterfaces();
+        // QList<QNetworkInterface> iface_list = QNetworkInterface::allInterfaces();
         QString iface = Settings::networkInterface();
         SetNetworkInterface(iface);
     }
 
-
     Uint16 i = 0;
     while (!Globals::instance().initTCPServer(port + i) && i < 10)
         i++;
@@ -111,13 +110,12 @@ void MagnetTest::update()
     try {
         bt::AuthenticationMonitor::instance().update();
         mdownloader->update();
-    } catch (bt::Error& err) {
+    } catch (bt::Error &err) {
         Out(SYS_GEN | LOG_IMPORTANT) << "Caught bt::Error: " << err.toString() << endl;
     }
 }
 
-
-void MagnetTest::foundMetaData(MagnetDownloader* md, const QByteArray& data)
+void MagnetTest::foundMetaData(MagnetDownloader *md, const QByteArray &data)
 {
     Q_UNUSED(md);
     Out(SYS_GEN | LOG_IMPORTANT) << "Saving to output.torrent" << endl;
@@ -132,7 +130,7 @@ void MagnetTest::foundMetaData(MagnetDownloader* md, const QByteArray& data)
             if (trs.count() > 1) {
                 enc.write(QByteArrayLiteral("announce-list"));
                 enc.beginList();
-                for (const QUrl& u : qAsConst(trs)) {
+                for (const QUrl &u : qAsConst(trs)) {
                     enc.write(u.toEncoded());
                 }
                 enc.end();
@@ -146,4 +144,3 @@ void MagnetTest::foundMetaData(MagnetDownloader* md, const QByteArray& data)
         Out(SYS_GEN | LOG_IMPORTANT) << "Failed to open output.torrent: " << fptr.errorString() << endl;
     }
 }
-
