@@ -25,43 +25,42 @@
 #include <QNetworkInterface>
 #include <QProgressBar>
 
-#include <KLocalizedString>
-#include <KIO/Job>
 #include <KIO/CopyJob>
+#include <KIO/Job>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KStandardGuiItem>
 
-#include <dbus/dbus.h>
-#include <interfaces/guiinterface.h>
-#include <interfaces/functions.h>
-#include <interfaces/torrentfileinterface.h>
-#include <torrent/magnetmanager.h>
-#include <torrent/queuemanager.h>
-#include <torrent/torrentcontrol.h>
-#include <torrent/torrentcreator.h>
-#include <torrent/server.h>
-#include <peer/authenticationmonitor.h>
-#include <util/log.h>
-#include <util/error.h>
-#include <util/fileops.h>
-#include <util/functions.h>
-#include <util/waitjob.h>
-#include <bcodec/bencoder.h>
-#include <bcodec/bnode.h>
-#include <plugin/pluginmanager.h>
-#include <groups/groupmanager.h>
-#include <groups/group.h>
-#include <dht/dht.h>
-#include <dht/dhtbase.h>
-#include <utp/utpserver.h>
-#include <net/socketmonitor.h>
-#include <torrent/jobqueue.h>
-#include "settings.h"
 #include "dialogs/fileselectdlg.h"
 #include "dialogs/missingfilesdlg.h"
 #include "gui.h"
 #include "powermanagementinhibit_interface.h"
-
+#include "settings.h"
+#include <bcodec/bencoder.h>
+#include <bcodec/bnode.h>
+#include <dbus/dbus.h>
+#include <dht/dht.h>
+#include <dht/dhtbase.h>
+#include <groups/group.h>
+#include <groups/groupmanager.h>
+#include <interfaces/functions.h>
+#include <interfaces/guiinterface.h>
+#include <interfaces/torrentfileinterface.h>
+#include <net/socketmonitor.h>
+#include <peer/authenticationmonitor.h>
+#include <plugin/pluginmanager.h>
+#include <torrent/jobqueue.h>
+#include <torrent/magnetmanager.h>
+#include <torrent/queuemanager.h>
+#include <torrent/server.h>
+#include <torrent/torrentcontrol.h>
+#include <torrent/torrentcreator.h>
+#include <util/error.h>
+#include <util/fileops.h>
+#include <util/functions.h>
+#include <util/log.h>
+#include <util/waitjob.h>
+#include <utp/utpserver.h>
 
 using namespace bt;
 
@@ -69,12 +68,12 @@ namespace kt
 {
 const Uint32 CORE_UPDATE_INTERVAL = 250;
 
-Core::Core(kt::GUI* gui)
-    : gui(gui),
-      keep_seeding(true),
-      sleep_suppression_cookie(0),
-      exiting(false),
-      reordering_queue(false)
+Core::Core(kt::GUI *gui)
+    : gui(gui)
+    , keep_seeding(true)
+    , sleep_suppression_cookie(0)
+    , exiting(false)
+    , reordering_queue(false)
 {
     UpdateCurrentTime();
     qman = new QueueManager();
@@ -108,7 +107,6 @@ Core::Core(kt::GUI* gui)
         SetNetworkInterface(iface);
     }
 
-
     startServers();
 
     mman = new kt::MagnetManager(this);
@@ -134,7 +132,6 @@ Core::~Core()
     delete gman;
 }
 
-
 void Core::startServers()
 {
     Uint16 port = Settings::port();
@@ -158,8 +155,7 @@ void Core::startTCPServer(bt::Uint16 port)
     if (Globals::instance().initTCPServer(port)) {
         Out(SYS_GEN | LOG_NOTICE) << "Bound to TCP port " << port << endl;
     } else {
-        gui->errorMsg(i18n("KTorrent is unable to accept connections because the TCP port %1 is "
-                           "already in use by another program.", port));
+        gui->errorMsg(i18n("KTorrent is unable to accept connections because the TCP port %1 is already in use by another program.", port));
         Out(SYS_GEN | LOG_IMPORTANT) << "Cannot find free TCP port" << endl;
     }
 }
@@ -169,16 +165,13 @@ bool Core::startUTPServer(bt::Uint16 port)
     if (Globals::instance().initUTPServer(port)) {
         Out(SYS_GEN | LOG_NOTICE) << "Bound to UDP port " << port << endl;
     } else {
-        gui->errorMsg(i18n("KTorrent is unable to accept connections because the UDP port %1 is "
-                           "already in use by another program.", port));
+        gui->errorMsg(i18n("KTorrent is unable to accept connections because the UDP port %1 is already in use by another program.", port));
         Out(SYS_GEN | LOG_IMPORTANT) << "Cannot find free UDP port" << endl;
         return false;
     }
     return true;
 }
 
-
-
 void Core::applySettings()
 {
     bt::Uint16 port = Settings::port();
@@ -187,7 +180,7 @@ void Core::applySettings()
     bool utp_enabled = Settings::utpEnabled();
     bool tcp_enabled = utp_enabled && Settings::onlyUseUtp() ? false : true;
 
-    bt::Globals& globals = bt::Globals::instance();
+    bt::Globals &globals = bt::Globals::instance();
 
     if (globals.isTCPEnabled() && !tcp_enabled)
         globals.shutdownTCPServer();
@@ -217,7 +210,7 @@ void Core::applySettings()
         tmp = kt::DataDir();
 
     changeDataDir(tmp);
-    //update QM
+    // update QM
     getQueueManager()->orderQueue();
 
     mman->setUseSlotTimer(Settings::requeueMagnets());
@@ -232,7 +225,7 @@ void Core::loadPlugins()
     pman->loadPluginList();
 }
 
-bool Core::init(TorrentControl* tc, const QString& group, const QString& location, bool silently)
+bool Core::init(TorrentControl *tc, const QString &group, const QString &location, bool silently)
 {
     bool start_torrent = false;
     bool skip_check = false;
@@ -264,15 +257,15 @@ bool Core::init(TorrentControl* tc, const QString& group, const QString& locatio
     } else
         start_torrent = true;
 
-
     QStringList conflicting;
     if (qman->checkFileConflicts(tc, conflicting)) {
         Out(SYS_GEN | LOG_IMPORTANT) << "Torrent " << tc->getDisplayName() << " conflicts with the following torrents: " << endl;
         Out(SYS_GEN | LOG_IMPORTANT) << conflicting.join(QStringLiteral(", ")) << endl;
         if (!silently) {
-            QString err = i18n("Opening the torrent <b>%1</b>, "
-                               "would share one or more files with the following torrents. "
-                               "Torrents are not allowed to write to the same files. ", tc->getDisplayName());
+            QString err = i18n(
+                "Opening the torrent <b>%1</b>, would share one or more files with the following torrents. "
+                "Torrents are not allowed to write to the same files. ",
+                tc->getDisplayName());
             KMessageBox::errorList(gui, err, conflicting);
         }
 
@@ -281,7 +274,7 @@ bool Core::init(TorrentControl* tc, const QString& group, const QString& locatio
 
     try {
         tc->createFiles();
-    } catch (bt::Error& err) {
+    } catch (bt::Error &err) {
         if (!silently)
             gui->errorMsg(err.toString());
         Out(SYS_GEN | LOG_IMPORTANT) << err.toString() << endl;
@@ -295,13 +288,12 @@ bool Core::init(TorrentControl* tc, const QString& group, const QString& locatio
             tc->markExistingFilesAsDownloaded();
     }
 
-
     tc->setPreallocateDiskSpace(true);
     connectSignals(tc);
     qman->append(tc);
     qman->torrentAdded(tc, start_torrent);
 
-    //now copy torrent file to user specified dir if needed
+    // now copy torrent file to user specified dir if needed
     if (Settings::useTorrentCopyDir()) {
         QString torFile = tc->getTorDir();
         if (!torFile.endsWith(bt::DirSeparator()))
@@ -317,7 +309,7 @@ bool Core::init(TorrentControl* tc, const QString& group, const QString& locatio
     }
 
     // add torrent to group if necessary
-    Group* g = gman->find(selected_group);
+    Group *g = gman->find(selected_group);
     if (g) {
         if (!g->isMember(tc)) {
             g->addTorrent(tc, true);
@@ -331,10 +323,10 @@ bool Core::init(TorrentControl* tc, const QString& group, const QString& locatio
     return true;
 }
 
-bt::TorrentInterface* Core::loadFromData(const QByteArray& data, const QString& dir, const QString& group, bool silently, const QUrl& url)
+bt::TorrentInterface *Core::loadFromData(const QByteArray &data, const QString &dir, const QString &group, bool silently, const QUrl &url)
 {
     QString tdir = findNewTorrentDir();
-    TorrentControl* tc = 0;
+    TorrentControl *tc = 0;
     try {
         tc = new TorrentControl();
         tc->setLoadUrl(url);
@@ -344,10 +336,10 @@ bt::TorrentInterface* Core::loadFromData(const QByteArray& data, const QString&
             startUpdateTimer();
             return tc;
         }
-    } catch (bt::Warning& warning) {
+    } catch (bt::Warning &warning) {
         bt::Out(SYS_GEN | LOG_NOTICE) << warning.toString() << endl;
         canNotLoadSilently(warning.toString());
-    } catch (bt::Error& err) {
+    } catch (bt::Error &err) {
         bt::Out(SYS_GEN | LOG_IMPORTANT) << err.toString() << endl;
         if (!silently)
             gui->errorMsg(err.toString());
@@ -364,12 +356,12 @@ bt::TorrentInterface* Core::loadFromData(const QByteArray& data, const QString&
     return 0;
 }
 
-bt::TorrentInterface* Core::loadFromFile(const QString& target, const QString& dir, const QString& group, bool silently)
+bt::TorrentInterface *Core::loadFromFile(const QString &target, const QString &dir, const QString &group, bool silently)
 {
     try {
         QByteArray data = bt::LoadFile(target);
         return loadFromData(data, dir, group, silently, QUrl::fromLocalFile(target));
-    } catch (bt::Error& err) {
+    } catch (bt::Error &err) {
         bt::Out(SYS_GEN | LOG_IMPORTANT) << err.toString() << endl;
         if (!silently)
             gui->errorMsg(err.toString());
@@ -379,9 +371,9 @@ bt::TorrentInterface* Core::loadFromFile(const QString& target, const QString& d
     }
 }
 
-void Core::downloadFinished(KJob* job)
+void Core::downloadFinished(KJob *job)
 {
-    KIO::StoredTransferJob* j = (KIO::StoredTransferJob*)job;
+    KIO::StoredTransferJob *j = (KIO::StoredTransferJob *)job;
     int err = j->error();
     if (err == KIO::ERR_USER_CANCELED)
         return;
@@ -403,7 +395,7 @@ void Core::downloadFinished(KJob* job)
     }
 }
 
-void Core::load(const QUrl& url, const QString& group)
+void Core::load(const QUrl &url, const QString &group)
 {
     if (url.scheme() == QLatin1String("magnet")) {
         MagnetLinkLoadOptions options;
@@ -416,16 +408,16 @@ void Core::load(const QUrl& url, const QString& group)
         if (dir != QString())
             loadFromFile(path, dir, group, false);
     } else {
-        KIO::Job* j = KIO::storedGet(url);
+        KIO::Job *j = KIO::storedGet(url);
         connect(j, &KIO::Job::result, this, &Core::downloadFinished);
         if (!group.isEmpty())
             add_to_groups.insert(url, group);
     }
 }
 
-void Core::downloadFinishedSilently(KJob* job)
+void Core::downloadFinishedSilently(KJob *job)
 {
-    KIO::StoredTransferJob* j = (KIO::StoredTransferJob*)job;
+    KIO::StoredTransferJob *j = (KIO::StoredTransferJob *)job;
     int err = j->error();
     if (err == KIO::ERR_USER_CANCELED) {
         // do nothing
@@ -453,13 +445,12 @@ void Core::downloadFinishedSilently(KJob* job)
             add_to_groups.erase(i);
         }
 
-
         if (dir != QString())
             loadFromData(j->data(), dir, group, true, j->url());
     }
 }
 
-void Core::loadSilently(const QUrl &url, const QString& group)
+void Core::loadSilently(const QUrl &url, const QString &group)
 {
     if (url.scheme() == QLatin1String("magnet")) {
         MagnetLinkLoadOptions options;
@@ -474,14 +465,14 @@ void Core::loadSilently(const QUrl &url, const QString& group)
             loadFromFile(path, dir, group, true);
     } else {
         // download to a random file in tmp
-        KIO::Job* j = KIO::storedGet(url);
+        KIO::Job *j = KIO::storedGet(url);
         connect(j, &KIO::Job::result, this, &Core::downloadFinishedSilently);
         if (!group.isEmpty())
             add_to_groups.insert(url, group);
     }
 }
 
-bt::TorrentInterface* Core::load(const QByteArray& data, const QUrl &url, const QString& group, const QString& savedir)
+bt::TorrentInterface *Core::load(const QByteArray &data, const QUrl &url, const QString &group, const QString &savedir)
 {
     QString dir;
     if (savedir.isEmpty() || !bt::Exists(savedir))
@@ -495,7 +486,7 @@ bt::TorrentInterface* Core::load(const QByteArray& data, const QUrl &url, const
         return 0;
 }
 
-bt::TorrentInterface* Core::loadSilently(const QByteArray& data, const QUrl &url, const QString& group, const QString& savedir)
+bt::TorrentInterface *Core::loadSilently(const QByteArray &data, const QUrl &url, const QString &group, const QString &savedir)
 {
     QString dir;
     if (savedir.isEmpty() || !bt::Exists(savedir))
@@ -509,7 +500,7 @@ bt::TorrentInterface* Core::loadSilently(const QByteArray& data, const QUrl &url
         return 0;
 }
 
-void Core::start(bt::TorrentInterface* tc)
+void Core::start(bt::TorrentInterface *tc)
 {
     if (tc->getStats().paused) {
         tc->unpause();
@@ -522,13 +513,13 @@ void Core::start(bt::TorrentInterface* tc)
     startUpdateTimer(); // restart update timer
 }
 
-void Core::start(QList<bt::TorrentInterface*> & todo)
+void Core::start(QList<bt::TorrentInterface *> &todo)
 {
     if (todo.isEmpty())
         return;
 
     // unpause paused torrents
-    for (QList<bt::TorrentInterface*>::iterator i = todo.begin(); i != todo.end();) {
+    for (QList<bt::TorrentInterface *>::iterator i = todo.begin(); i != todo.end();) {
         if ((*i)->getStats().paused) {
             (*i)->unpause();
             i = todo.erase(i);
@@ -545,24 +536,24 @@ void Core::start(QList<bt::TorrentInterface*> & todo)
     startUpdateTimer(); // restart update timer
 }
 
-void Core::stop(bt::TorrentInterface* tc)
+void Core::stop(bt::TorrentInterface *tc)
 {
     qman->stop(tc);
 }
 
-void Core::stop(QList<bt::TorrentInterface*> & todo)
+void Core::stop(QList<bt::TorrentInterface *> &todo)
 {
     qman->stop(todo);
 }
 
-void Core::pause(TorrentInterface* tc)
+void Core::pause(TorrentInterface *tc)
 {
     tc->pause();
 }
 
-void Core::pause(QList<bt::TorrentInterface*>& todo)
+void Core::pause(QList<bt::TorrentInterface *> &todo)
 {
-    for (bt::TorrentInterface* tc : qAsConst(todo)) {
+    for (bt::TorrentInterface *tc : qAsConst(todo)) {
         tc->pause();
     }
 }
@@ -581,9 +572,9 @@ QString Core::findNewTorrentDir() const
     return QString();
 }
 
-void Core::loadExistingTorrent(const QString& tor_dir)
+void Core::loadExistingTorrent(const QString &tor_dir)
 {
-    TorrentControl* tc = 0;
+    TorrentControl *tc = 0;
 
     QString idir = tor_dir;
     if (!idir.endsWith(bt::DirSeparator()))
@@ -599,10 +590,10 @@ void Core::loadExistingTorrent(const QString& tor_dir)
         qman->append(tc);
         connectSignals(tc);
         torrentAdded(tc);
-    } catch (bt::Error& err) {
+    } catch (bt::Error &err) {
         gui->errorMsg(err.toString());
         delete tc;
-    } catch (bt::Warning& warning) {
+    } catch (bt::Warning &warning) {
         bt::Out(SYS_GEN | LOG_NOTICE) << warning.toString() << endl;
         canNotLoadSilently(warning.toString());
         bt::Delete(tor_dir, true);
@@ -615,7 +606,7 @@ void Core::loadTorrents()
     QStringList filters;
     filters << QStringLiteral("tor*");
     const QStringList sl = dir.entryList(filters, QDir::Dirs);
-    for (const QString& s : sl) {
+    for (const QString &s : sl) {
         QString idir = data_dir + s;
         if (!idir.endsWith(DirSeparator()))
             idir.append(DirSeparator());
@@ -636,8 +627,7 @@ void Core::delayedStart()
         qman->startAutoStartTorrents();
 }
 
-
-void Core::remove(bt::TorrentInterface* tc, bool data_to)
+void Core::remove(bt::TorrentInterface *tc, bool data_to)
 {
     try {
         if (tc->getJobQueue()->runningJobs()) {
@@ -647,7 +637,7 @@ void Core::remove(bt::TorrentInterface* tc, bool data_to)
             return;
         }
 
-        const bt::TorrentStats& s = tc->getStats();
+        const bt::TorrentStats &s = tc->getStats();
         removed_bytes_up += s.session_bytes_uploaded;
         removed_bytes_down += s.session_bytes_downloaded;
         stop(tc);
@@ -657,7 +647,7 @@ void Core::remove(bt::TorrentInterface* tc, bool data_to)
         try {
             if (data_to)
                 tc->deleteDataFiles();
-        } catch (Error& e) {
+        } catch (Error &e) {
             gui->errorMsg(e.toString());
         }
 
@@ -667,16 +657,16 @@ void Core::remove(bt::TorrentInterface* tc, bool data_to)
         gui->updateActions();
         bt::Delete(dir, false);
         delayed_removal.remove(tc);
-    } catch (Error& e) {
+    } catch (Error &e) {
         gui->errorMsg(e.toString());
     }
 }
 
-void Core::remove(QList<bt::TorrentInterface*> & todo, bool data_to)
+void Core::remove(QList<bt::TorrentInterface *> &todo, bool data_to)
 {
-    QList<bt::TorrentInterface*>::iterator i = todo.begin();
+    QList<bt::TorrentInterface *>::iterator i = todo.begin();
     while (i != todo.end()) {
-        bt::TorrentInterface* tc = *i;
+        bt::TorrentInterface *tc = *i;
         if (tc->getJobQueue()->runningJobs()) {
             // if there are running jobs, schedule delete when they finish
             delayed_removal.insert(tc, data_to);
@@ -688,8 +678,8 @@ void Core::remove(QList<bt::TorrentInterface*> & todo, bool data_to)
 
     stop(todo);
 
-    for (bt::TorrentInterface* tc : qAsConst(todo)) {
-        const bt::TorrentStats& s = tc->getStats();
+    for (bt::TorrentInterface *tc : qAsConst(todo)) {
+        const bt::TorrentStats &s = tc->getStats();
         removed_bytes_up += s.session_bytes_uploaded;
         removed_bytes_down += s.session_bytes_downloaded;
 
@@ -698,7 +688,7 @@ void Core::remove(QList<bt::TorrentInterface*> & todo, bool data_to)
         try {
             if (data_to)
                 tc->deleteDataFiles();
-        } catch (Error& e) {
+        } catch (Error &e) {
             gui->errorMsg(e.toString());
         }
 
@@ -706,7 +696,7 @@ void Core::remove(QList<bt::TorrentInterface*> & todo, bool data_to)
         gman->torrentRemoved(tc);
         try {
             bt::Delete(dir, false);
-        } catch (Error& e) {
+        } catch (Error &e) {
             gui->errorMsg(e.toString());
         }
     }
@@ -715,7 +705,7 @@ void Core::remove(QList<bt::TorrentInterface*> & todo, bool data_to)
     gui->updateActions();
 }
 
-void Core::delayedRemove(bt::TorrentInterface* tc)
+void Core::delayedRemove(bt::TorrentInterface *tc)
 {
     if (!delayed_removal.contains(tc))
         return;
@@ -733,7 +723,7 @@ void Core::setMaxSeeds(int max)
     qman->setMaxSeeds(max);
 }
 
-void Core::torrentFinished(bt::TorrentInterface* tc)
+void Core::torrentFinished(bt::TorrentInterface *tc)
 {
     if (!keep_seeding)
         tc->stop();
@@ -762,7 +752,7 @@ void Core::onExit()
     // stop all authentications going on
     AuthenticationMonitor::instance().shutdown();
 
-    WaitJob* job = new WaitJob(5000);
+    WaitJob *job = new WaitJob(5000);
     qman->saveState(KSharedConfig::openConfig());
 
     // Sync the config to be sure everything is saved
@@ -783,7 +773,7 @@ void Core::onExit()
     qman->clear();
 }
 
-bool Core::changeDataDir(const QString& new_dir)
+bool Core::changeDataDir(const QString &new_dir)
 {
     try {
         // do nothing if new and old dir are the same
@@ -797,7 +787,6 @@ bool Core::changeDataDir(const QString& new_dir)
         if (!bt::Exists(new_dir))
             bt::MakeDir(new_dir);
 
-
         // make sure new_dir ends with a /
         QString nd = new_dir;
         if (!nd.endsWith(DirSeparator()))
@@ -807,11 +796,11 @@ bool Core::changeDataDir(const QString& new_dir)
 
         qman->setSuspendedState(true);
 
-        QList<bt::TorrentInterface*> succes;
+        QList<bt::TorrentInterface *> succes;
 
-        QList<bt::TorrentInterface*>::iterator i = qman->begin();
+        QList<bt::TorrentInterface *>::iterator i = qman->begin();
         while (i != qman->end()) {
-            bt::TorrentInterface* tc = *i;
+            bt::TorrentInterface *tc = *i;
             if (!tc->changeTorDir(nd)) {
                 // failure time to roll back all the successful tc's
                 rollback(succes);
@@ -830,18 +819,18 @@ bool Core::changeDataDir(const QString& new_dir)
         qman->setSuspendedState(false);
         update_timer.start(CORE_UPDATE_INTERVAL);
         return true;
-    } catch (bt::Error& e) {
+    } catch (bt::Error &e) {
         Out(SYS_GEN | LOG_IMPORTANT) << "Error : " << e.toString() << endl;
         update_timer.start(CORE_UPDATE_INTERVAL);
         return false;
     }
 }
 
-void Core::rollback(const QList<bt::TorrentInterface*> & succes)
+void Core::rollback(const QList<bt::TorrentInterface *> &succes)
 {
     Out(SYS_GEN | LOG_DEBUG) << "Error, rolling back" << endl;
     update_timer.stop();
-    QList<bt::TorrentInterface*>::const_iterator i = succes.begin();
+    QList<bt::TorrentInterface *>::const_iterator i = succes.begin();
     while (i != succes.end()) {
         (*i)->rollback();
         i++;
@@ -866,10 +855,12 @@ void Core::startUpdateTimer()
         Out(SYS_GEN | LOG_DEBUG) << "Started update timer" << endl;
         update_timer.start(CORE_UPDATE_INTERVAL);
         if (Settings::suppressSleep() && sleep_suppression_cookie == 0) {
-            org::freedesktop::PowerManagement::Inhibit powerManagement(QStringLiteral("org.freedesktop.PowerManagement.Inhibit"), QStringLiteral("/org/freedesktop/PowerManagement/Inhibit"), QDBusConnection::sessionBus());
+            org::freedesktop::PowerManagement::Inhibit powerManagement(QStringLiteral("org.freedesktop.PowerManagement.Inhibit"),
+                                                                       QStringLiteral("/org/freedesktop/PowerManagement/Inhibit"),
+                                                                       QDBusConnection::sessionBus());
             QDBusPendingReply<quint32> pendingReply = powerManagement.Inhibit(QStringLiteral("ktorrent"), i18n("KTorrent is running one or more torrents"));
             auto pendingCallWatcher = new QDBusPendingCallWatcher(pendingReply, this);
-            connect(pendingCallWatcher, &QDBusPendingCallWatcher::finished, this, [ = ](QDBusPendingCallWatcher * callWatcher) {
+            connect(pendingCallWatcher, &QDBusPendingCallWatcher::finished, this, [=](QDBusPendingCallWatcher *callWatcher) {
                 QDBusPendingReply<quint32> reply = *callWatcher;
                 if (reply.isValid()) {
                     sleep_suppression_cookie = reply.value();
@@ -890,10 +881,10 @@ void Core::update()
         bt::UpdateCurrentTime();
         AuthenticationMonitor::instance().update();
 
-        QList<bt::TorrentInterface*>::iterator i = qman->begin();
+        QList<bt::TorrentInterface *>::iterator i = qman->begin();
         bool updated = false;
         while (i != qman->end()) {
-            bt::TorrentInterface* tc = *i;
+            bt::TorrentInterface *tc = *i;
             if (tc->getStats().running) {
                 tc->update();
                 updated = true;
@@ -906,10 +897,12 @@ void Core::update()
             update_timer.stop(); // stop timer when not necessary
 
             if (sleep_suppression_cookie) {
-                org::freedesktop::PowerManagement::Inhibit powerManagement(QStringLiteral("org.freedesktop.PowerManagement.Inhibit"), QStringLiteral("/org/freedesktop/PowerManagement/Inhibit"), QDBusConnection::sessionBus());
+                org::freedesktop::PowerManagement::Inhibit powerManagement(QStringLiteral("org.freedesktop.PowerManagement.Inhibit"),
+                                                                           QStringLiteral("/org/freedesktop/PowerManagement/Inhibit"),
+                                                                           QDBusConnection::sessionBus());
                 auto pendingReply = powerManagement.UnInhibit(sleep_suppression_cookie);
                 auto pendingCallWatcher = new QDBusPendingCallWatcher(pendingReply, this);
-                connect(pendingCallWatcher, &QDBusPendingCallWatcher::finished, this, [ = ](QDBusPendingCallWatcher * callWatcher) {
+                connect(pendingCallWatcher, &QDBusPendingCallWatcher::finished, this, [=](QDBusPendingCallWatcher *callWatcher) {
                     QDBusPendingReply<void> reply = *callWatcher;
                     if (reply.isValid()) {
                         sleep_suppression_cookie = 0;
@@ -925,17 +918,17 @@ void Core::update()
                 qman->checkStalledTorrents(bt::CurrentTime(), Settings::stallTimer());
             }
         }
-    } catch (bt::Error& err) {
+    } catch (bt::Error &err) {
         Out(SYS_GEN | LOG_IMPORTANT) << "Caught bt::Error: " << err.toString() << endl;
     }
 }
 
-bt::TorrentInterface* Core::createTorrent(bt::TorrentCreator* mktor, bool seed)
+bt::TorrentInterface *Core::createTorrent(bt::TorrentCreator *mktor, bool seed)
 {
     QString tdir;
     try {
         tdir = findNewTorrentDir();
-        bt::TorrentControl* tc = mktor->makeTC(tdir);
+        bt::TorrentControl *tc = mktor->makeTC(tdir);
         if (tc) {
             connectSignals(tc);
             qman->append(tc);
@@ -944,7 +937,7 @@ bt::TorrentInterface* Core::createTorrent(bt::TorrentCreator* mktor, bool seed)
             torrentAdded(tc);
             return tc;
         }
-    } catch (bt::Error& e) {
+    } catch (bt::Error &e) {
         // cleanup if necessary
         if (bt::Exists(tdir))
             bt::Delete(tdir, true);
@@ -955,16 +948,14 @@ bt::TorrentInterface* Core::createTorrent(bt::TorrentCreator* mktor, bool seed)
     return 0;
 }
 
-
 CurrentStats Core::getStats()
 {
     CurrentStats stats;
     Uint64 bytes_dl = 0, bytes_ul = 0;
     Uint32 speed_dl = 0, speed_ul = 0;
 
-
-    for (bt::TorrentInterface* tc : qAsConst(*qman)) {
-        const TorrentStats& s = tc->getStats();
+    for (bt::TorrentInterface *tc : qAsConst(*qman)) {
+        const TorrentStats &s = tc->getStats();
         speed_dl += s.download_rate;
         speed_ul += s.upload_rate;
         bytes_dl += s.session_bytes_downloaded;
@@ -980,25 +971,25 @@ CurrentStats Core::getStats()
 
 bool Core::changePort(Uint16 port)
 {
-    bt::Globals& globals = bt::Globals::instance();
+    bt::Globals &globals = bt::Globals::instance();
     bool ok = false;
     if (Settings::utpEnabled()) {
         globals.shutdownUTPServer();
         ok = startUTPServer(port);
 
         if (!Settings::onlyUseUtp()) {
-            bt::Server& srv = globals.getTCPServer();
+            bt::Server &srv = globals.getTCPServer();
             ok = ok && srv.changePort(port);
         }
     } else {
-        bt::Server& srv = globals.getTCPServer();
+        bt::Server &srv = globals.getTCPServer();
         ok = srv.changePort(port);
     }
 
     return ok;
 }
 
-void Core::slotStoppedByError(bt::TorrentInterface* tc, QString msg)
+void Core::slotStoppedByError(bt::TorrentInterface *tc, QString msg)
 {
     Q_EMIT torrentStoppedByError(tc, msg);
 }
@@ -1013,15 +1004,15 @@ Uint32 Core::getNumTorrentsNotRunning() const
     return qman->count() - qman->getNumRunning();
 }
 
-kt::QueueManager* Core::getQueueManager()
+kt::QueueManager *Core::getQueueManager()
 {
     return this->qman;
 }
 
-void Core::torrentSeedAutoStopped(bt::TorrentInterface* tc, AutoStopReason reason)
+void Core::torrentSeedAutoStopped(bt::TorrentInterface *tc, AutoStopReason reason)
 {
     qman->startNext();
-    if (reason ==  MAX_RATIO_REACHED)
+    if (reason == MAX_RATIO_REACHED)
         maxShareRatioReached(tc);
     else
         maxSeedTimeReached(tc);
@@ -1040,7 +1031,7 @@ bool Core::getSuspendedState()
     return qman->getSuspendedState();
 }
 
-bool Core::checkMissingFiles(TorrentInterface* tc)
+bool Core::checkMissingFiles(TorrentInterface *tc)
 {
     QStringList missing;
     if (!tc->hasMissingFiles(missing))
@@ -1068,9 +1059,9 @@ bool Core::checkMissingFiles(TorrentInterface* tc)
 
     if (tc->getStats().multi_file_torrent) {
         QString msg = i18n(
-                          "Several data files of the torrent \"%1\" are missing. \n"
-                          "Do you want to recreate them, or do you want to not download them?",
-                          tc->getStats().torrent_name);
+            "Several data files of the torrent \"%1\" are missing. \n"
+            "Do you want to recreate them, or do you want to not download them?",
+            tc->getStats().torrent_name);
 
         MissingFilesDlg dlg(msg, missing, tc, 0);
 
@@ -1082,7 +1073,7 @@ bool Core::checkMissingFiles(TorrentInterface* tc)
             try {
                 // mark them as do not download
                 tc->dndMissingFiles();
-            } catch (bt::Error& e) {
+            } catch (bt::Error &e) {
                 gui->errorMsg(i18n("Cannot deselect missing files: %1", e.toString()));
                 tc->handleError(i18n("Data files are missing"));
                 return false;
@@ -1092,7 +1083,7 @@ bool Core::checkMissingFiles(TorrentInterface* tc)
             try {
                 // recreate them
                 tc->recreateMissingFiles();
-            } catch (bt::Error& e) {
+            } catch (bt::Error &e) {
                 KMessageBox::error(0, i18n("Cannot recreate missing files: %1", e.toString()));
                 tc->handleError(i18n("Data files are missing"));
                 return false;
@@ -1102,8 +1093,10 @@ bool Core::checkMissingFiles(TorrentInterface* tc)
             break;
         }
     } else {
-        QString msg = i18n("The file where the data is saved of the torrent \"%1\" is missing.\n"
-                           "Do you want to recreate it?", tc->getStats().torrent_name);
+        QString msg = i18n(
+            "The file where the data is saved of the torrent \"%1\" is missing.\n"
+            "Do you want to recreate it?",
+            tc->getStats().torrent_name);
         MissingFilesDlg dlg(msg, missing, tc, 0);
 
         switch (dlg.execute()) {
@@ -1113,7 +1106,7 @@ bool Core::checkMissingFiles(TorrentInterface* tc)
         case MissingFilesDlg::RECREATE:
             try {
                 tc->recreateMissingFiles();
-            } catch (bt::Error& e) {
+            } catch (bt::Error &e) {
                 gui->errorMsg(i18n("Cannot recreate data file: %1", e.toString()));
                 tc->handleError(i18n("Data file is missing"));
                 return false;
@@ -1129,19 +1122,17 @@ bool Core::checkMissingFiles(TorrentInterface* tc)
     return true;
 }
 
-
-void Core::aboutToBeStarted(bt::TorrentInterface* tc, bool& ret)
+void Core::aboutToBeStarted(bt::TorrentInterface *tc, bool &ret)
 {
     ret = checkMissingFiles(tc);
 }
 
-void Core::emitCorruptedData(bt::TorrentInterface* tc)
+void Core::emitCorruptedData(bt::TorrentInterface *tc)
 {
     corruptedData(tc);
-
 }
 
-void Core::connectSignals(bt::TorrentInterface* tc)
+void Core::connectSignals(bt::TorrentInterface *tc)
 {
     connect(tc, &bt::TorrentInterface::finished, this, &Core::torrentFinished);
     connect(tc, &bt::TorrentInterface::stoppedByError, this, &Core::slotStoppedByError);
@@ -1157,26 +1148,24 @@ float Core::getGlobalMaxShareRatio() const
     return Settings::maxRatio();
 }
 
-void Core::enqueueTorrentOverMaxRatio(bt::TorrentInterface* tc)
+void Core::enqueueTorrentOverMaxRatio(bt::TorrentInterface *tc)
 {
     Q_EMIT queuingNotPossible(tc);
 }
 
-void Core::autoCheckData(bt::TorrentInterface* tc)
+void Core::autoCheckData(bt::TorrentInterface *tc)
 {
-    Out(SYS_GEN | LOG_IMPORTANT) << "Doing an automatic data check on "
-                                 << tc->getStats().torrent_name << endl;
+    Out(SYS_GEN | LOG_IMPORTANT) << "Doing an automatic data check on " << tc->getStats().torrent_name << endl;
 
     doDataCheck(tc);
 }
 
-void Core::doDataCheck(bt::TorrentInterface* tc, bool auto_import)
+void Core::doDataCheck(bt::TorrentInterface *tc, bool auto_import)
 {
     tc->startDataCheck(auto_import, 0, tc->getStats().total_chunks);
 }
 
-
-void Core::onLowDiskSpace(bt::TorrentInterface* tc, bool stopped)
+void Core::onLowDiskSpace(bt::TorrentInterface *tc, bool stopped)
 {
     Q_EMIT lowDiskSpace(tc, stopped);
 }
@@ -1186,12 +1175,12 @@ void Core::updateGuiPlugins()
     pman->updateGuiPlugins();
 }
 
-DBus* Core::getExternalInterface()
+DBus *Core::getExternalInterface()
 {
     return gui->getDBusInterface();
 }
 
-void Core::onStatusChanged(bt::TorrentInterface* tc)
+void Core::onStatusChanged(bt::TorrentInterface *tc)
 {
     Q_UNUSED(tc);
     if (!reordering_queue)
@@ -1216,24 +1205,22 @@ void Core::customGroupChanged()
     gman->updateCount(qman);
 }
 
-
-void Core::load(const bt::MagnetLink& mlink, const MagnetLinkLoadOptions& options)
+void Core::load(const bt::MagnetLink &mlink, const MagnetLinkLoadOptions &options)
 {
     if (!mlink.isValid()) {
         gui->errorMsg(i18n("Invalid magnet bittorrent link: %1", mlink.toString()));
     } else {
         if (!Globals::instance().getDHT().isRunning())
-            dhtNotEnabled(i18n("You are attempting to download a magnet link, and DHT is not enabled. "
-                               "For optimum results enable DHT."));
+            dhtNotEnabled(i18n("You are attempting to download a magnet link, and DHT is not enabled. For optimum results enable DHT."));
         mman->addMagnet(mlink, options, false);
         startUpdateTimer();
     }
 }
 
-void Core::onMetadataDownloaded(const bt::MagnetLink& mlink, const QByteArray& data, const kt::MagnetLinkLoadOptions& options)
+void Core::onMetadataDownloaded(const bt::MagnetLink &mlink, const QByteArray &data, const kt::MagnetLinkLoadOptions &options)
 {
     QByteArray tmp;
-    BEncoderBufferOutput* out = new BEncoderBufferOutput(tmp);
+    BEncoderBufferOutput *out = new BEncoderBufferOutput(tmp);
     BEncoder enc(out);
     enc.beginDict();
     QList<QUrl> trs = mlink.trackers();
@@ -1257,7 +1244,7 @@ void Core::onMetadataDownloaded(const bt::MagnetLink& mlink, const QByteArray& d
 
     QUrl url(mlink.toString());
 
-    bt::TorrentInterface* tc = 0;
+    bt::TorrentInterface *tc = 0;
     if (options.silently)
         tc = loadSilently(tmp, url, options.group, options.location);
     else
@@ -1267,13 +1254,12 @@ void Core::onMetadataDownloaded(const bt::MagnetLink& mlink, const QByteArray& d
         tc->setMoveWhenCompletedDir(options.move_on_completion);
 }
 
-
-QString Core::locationHint(const QString& group) const
+QString Core::locationHint(const QString &group) const
 {
     QString dir;
 
     // First see if we can use the group settings
-    Group* g = gman->find(group);
+    Group *g = gman->find(group);
     QString group_save_location = g != 0 ? g->groupPolicy().default_save_location : QString();
     if (!group_save_location.isEmpty() && bt::Exists(group_save_location))
         dir = g->groupPolicy().default_save_location;
@@ -1282,7 +1268,6 @@ QString Core::locationHint(const QString& group) const
     else
         dir = Settings::lastSaveDir();
 
-
     if (dir.isEmpty() || !bt::Exists(dir))
         dir = QDir::homePath();
 
