@@ -1,43 +1,43 @@
 /***************************************************************************
-*   Copyright (C) 2005 by Joris Guisson                                   *
-*   joris.guisson@gmail.com                                               *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
-***************************************************************************/
+ *   Copyright (C) 2005 by Joris Guisson                                   *
+ *   joris.guisson@gmail.com                                               *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ ***************************************************************************/
 
 #include <QCloseEvent>
 #include <QTimer>
 
 #include <KMessageBox>
 
-#include <util/log.h>
-#include <util/constants.h>
-#include <torrent/globals.h>
 #include <interfaces/coreinterface.h>
+#include <torrent/globals.h>
+#include <util/constants.h>
+#include <util/log.h>
 
 #include "convertdialog.h"
 #include "convertthread.h"
 
-
 using namespace bt;
 
 namespace kt
 {
-
-ConvertDialog::ConvertDialog(QWidget* parent) : QDialog(parent), convert_thread(nullptr)
+ConvertDialog::ConvertDialog(QWidget *parent)
+    : QDialog(parent)
+    , convert_thread(nullptr)
 {
     setupUi(this);
     setModal(false);
@@ -53,7 +53,7 @@ ConvertDialog::~ConvertDialog()
 {
 }
 
-void ConvertDialog::message(const QString& msg)
+void ConvertDialog::message(const QString &msg)
 {
     QMutexLocker lock(&mutex);
     this->msg = msg;
@@ -105,8 +105,7 @@ void ConvertDialog::threadFinished()
     }
 }
 
-
-void ConvertDialog::closeEvent(QCloseEvent* e)
+void ConvertDialog::closeEvent(QCloseEvent *e)
 {
     if (!convert_thread)
         e->accept();
@@ -122,4 +121,3 @@ void ConvertDialog::btnCancelClicked()
 }
 
 }
-
